﻿using System;
using System.Windows.Forms;
using System.IO;

namespace PropertyEditorCS
{
    public partial class frmMain : Form
    {
        private const string TITLE = "Java プロパティエディタ";

        private string filepath = null;

        public frmMain()
        {
            InitializeComponent();
        }

        public frmMain(string filepath)
        {
            InitializeComponent();
            this.filepath = filepath;
        }

        private void 読込RToolStripMenuItem_Click(object sender, EventArgs e)
        {
            loadFile();
        }

        private void 保存SToolStripMenuItem_Click(object sender, EventArgs e)
        {
            saveFile();
        }

        private void 終了XToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.Dispose();
        }

        private void loadFile()
        {
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                this.filepath = openFileDialog1.FileName;
                this.SetTitle();
                this.load();
            }
        }

        private void saveFile()
        {
            DialogResult dr = DialogResult.No;
            if (this.filepath != null)
            {
                dr = MessageBox.Show("上書きします。よろしいですか？", "上書きの確認",
                    MessageBoxButtons.YesNoCancel, MessageBoxIcon.Question);
            }

            switch (dr)
            {
                case DialogResult.Yes:
                    this.save();
                    break;

                case DialogResult.No:
                    if (saveFileDialog1.ShowDialog() == DialogResult.OK)
                    {
                        this.filepath = saveFileDialog1.FileName;
                        this.SetTitle();
                        this.save();
                    }
                    break;

                default:
                    break;

            }
        }

        private void load()
        {
            using (StreamReader sr = new StreamReader(this.filepath))
            {
                string text = sr.ReadToEnd();
                this.textBox1.Text = Native2Acscii.Unescape(text);
            }
            this.textBox1.Select(0, 0);
        }

        private void save()
        {
            using (StreamWriter sw = new StreamWriter(this.filepath))
            {
                string text = this.textBox1.Text;
                sw.Write(Native2Acscii.Escape(text));
            }
        }

        private void SetTitle()
        {
            this.Text = TITLE;
            if (this.filepath != null)
            {
                this.Text += " - " + Path.GetFileName(this.filepath);
            }
        }

        private void frmMain_Load(object sender, EventArgs e)
        {
            if (this.filepath != null)
            {
                this.SetTitle();
                this.load();
            }
        }

        private void バージョン情報VToolStripMenuItem_Click(object sender, EventArgs e)
        {
            MessageBox.Show("Java プロパティエディタ Ver.1.0\nby Y.Kiuchi", "バージョン情報",
                MessageBoxButtons.OK, MessageBoxIcon.Information);
        }
    }
}